@@ -12,6 +12,8 @@ __metaclass__ = type
 
 import os.path as osp
 import os
+import subprocess
+import sys
 import tempfile
 
 def escape(value):
@@ -80,12 +82,15 @@ class DotBackend:
             storedir, basename, target = target_info_from_filename(outputfile)
             if target != "dot":
                 pdot, dot_sourcepath = tempfile.mkstemp(".dot", name)
+                os.close(pdot)
             else:
                 dot_sourcepath = osp.join(storedir, dotfile)
         else:
             target = 'png'
             pdot, dot_sourcepath = tempfile.mkstemp(".dot", name)
             ppng, outputfile = tempfile.mkstemp(".png", name)
+            os.close(pdot)
+            os.close(ppng)
         pdot = open(dot_sourcepath,'w')
         if isinstance(self.source, unicode):
             pdot.write(self.source.encode('UTF8'))
@@ -93,8 +98,8 @@ class DotBackend:
             pdot.write(self.source)
         pdot.close()
         if target != 'dot':
-            os.system('%s -T%s %s -o%s' % (self.renderer, target,
-                        dot_sourcepath, outputfile))
+            subprocess.call('%s -T%s %s -o%s' % (self.renderer, target,
+                            dot_sourcepath, outputfile), shell=True)
             os.unlink(dot_sourcepath)
         return outputfile
 
