@@ -108,7 +108,7 @@ pytest --coverage test_foo.py
 import os, sys, re
 import os.path as osp
 from time import time, clock
-
+import warnings
 
 from logilab.common.fileutils import abspath_listdir
 from logilab.common import testlib
@@ -332,14 +332,23 @@ class PyTester(object):
         self.cvg = cvg
         self.options = options
         self.firstwrite = True
+        self._errcode = None
 
     def show_report(self):
         """prints the report and returns appropriate exitcode"""
         # everything has been ran, print report
         print "*" * 79
         print self.report
+
+    def get_errcode(self):
+        # errcode set explicity
+        if self._errcode is not None:
+            return self._errcode
         return self.report.failures + self.report.errors
 
+    def set_errcode(self, errcode):
+        self._errcode = errcode
+    errcode = property(get_errcode, set_errcode)
 
     def testall(self, exitfirst=False):
         """walks trhough current working directory, finds something
@@ -404,21 +413,19 @@ succeeded test file :", osp.join(os.getcwd(),testlib.FILE_RESTART)
 succeeded test file :", osp.join(os.getcwd(),testlib.FILE_RESTART)
                 raise e
         modname = osp.basename(filename)[:-3]
-        if batchmode:
-            from cStringIO import StringIO
-            outstream = StringIO()
-        else:
-            outstream = sys.stderr
         try:
-            print >> outstream, ('  %s  ' % osp.basename(filename)).center(70, '=')
+            print >> sys.stderr, ('  %s  ' % osp.basename(filename)).center(70, '=')
         except TypeError: # < py 2.4 bw compat
-            print >> outstream, ('  %s  ' % osp.basename(filename)).center(70)
+            print >> sys.stderr, ('  %s  ' % osp.basename(filename)).center(70)
         try:
             tstart, cstart = time(), clock()
             try:
                 testprog = testlib.unittest_main(modname, batchmode=batchmode, cvg=self.cvg,
-                                                 options=self.options, outstream=outstream)
-            except (KeyboardInterrupt, SystemExit):
+                                                 options=self.options, outstream=sys.stderr)
+            except KeyboardInterrupt:
+                raise
+            except SystemExit, exc:
+                self.errcode = exc.code
                 raise
             except testlib.TestSkipped:
                 print "Module skipped:", filename
@@ -426,17 +433,13 @@ succeeded test file :", osp.join(os.getcwd(),testlib.FILE_RESTART)
                 return None
             except Exception:
                 self.report.failed_to_test_module(filename)
-                print >> outstream, 'unhandled exception occured while testing', modname
+                print >> sys.stderr, 'unhandled exception occured while testing', modname
                 import traceback
-                traceback.print_exc(file=outstream)
-                if batchmode:
-                    print >> sys.stderr, outstream.getvalue()
+                traceback.print_exc(file=sys.stderr)
                 return None
 
             tend, cend = time(), clock()
             ttime, ctime = (tend - tstart), (cend - cstart)
-            if testprog.result.testsRun and batchmode:
-                print >> sys.stderr, outstream.getvalue()
             self.report.feed(filename, testprog.result, ttime, ctime)
             return testprog
         finally:
@@ -573,7 +576,6 @@ def make_parser():
         """carry the option to unittest_main"""
         parser.newargs.append(opt)
 
-
     def rebuild_and_store(option, opt, value, parser):
         """carry the option to unittest_main and store
         the value on current parser
@@ -581,6 +583,10 @@ def make_parser():
         parser.newargs.append(opt)
         setattr(parser.values, option.dest, True)
 
+    def capture_and_rebuild(option, opt, value, parser):
+        warnings.simplefilter('ignore', DeprecationWarning)
+        rebuild_cmdline(option, opt, value, parser)
+
     # pytest options
     parser.add_option('-t', dest='testdir', default=None,
                       help="directory where the tests will be found")
@@ -601,7 +607,7 @@ def make_parser():
                       action="callback",
                       help="Restart tests from where it failed (implies exitfirst) "
                         "(only make sense if tests previously ran with exitfirst only)")
-    parser.add_option('-c', '--capture', callback=rebuild_cmdline,
+    parser.add_option('-c', '--capture', callback=capture_and_rebuild,
                       action="callback",
                       help="Captures and prints standard out/err only on errors "
                       "(only make sense when pytest run one test file)")
@@ -719,7 +725,7 @@ def run():
             import traceback
             traceback.print_exc()
     finally:
-        errcode = tester.show_report()
+        tester.show_report()
         if covermode:
             cvg.stop()
             cvg.save()
@@ -732,4 +738,4 @@ def run():
                   morfdir
             cvg.annotate([morfdir])
             cvg.report([morfdir], False)
-        sys.exit(errcode)
+        sys.exit(tester.errcode)
