@@ -13,6 +13,12 @@ LOW = 0
 MEDIUM = 10
 HIGH = 100
 
+REVERSE_PRIORITY = {
+    0: 'LOW',
+    10: 'MEDIUM',
+    100: 'HIGH'
+    }
+
 
 class PrioritizedTasksQueue(Queue):
 
