@@ -2,6 +2,8 @@
 unit tests for module logilab.common.db
 """
 
+import os
+import pwd
 import socket
 
 from logilab.common.testlib import TestCase, unittest_main
@@ -13,15 +15,22 @@ from logilab.common.adbh import (_GenericAdvFuncHelper, _SqliteAdvFuncHelper,
                                  auto_register_function)
 
 
+def getlogin():
+    """avoid usinng os.getlogin() because of strange tty / stdin problems
+    (man 3 getlogin)
+    Another solution would be to use $LOGNAME, $USER or $USERNAME
+    """
+    return pwd.getpwuid(os.getuid())[0]
+
 class PreferedDriverTC(TestCase):
     def setUp(self):
         self.drivers = {"pg":[('foo', None), ('bar', None)]}
         self.drivers = {'pg' : ["foo", "bar"]}
-        
+
     def testNormal(self):
         set_prefered_driver('pg','bar', self.drivers)
         self.assertEquals('bar', self.drivers['pg'][0])
-    
+
     def testFailuresDb(self):
         try:
             set_prefered_driver('oracle','bar', self.drivers)
@@ -52,13 +61,15 @@ class PreferedDriverTC(TestCase):
 
 class GetCnxTC(TestCase):
     def setUp(self):
-        if not socket.gethostname().startswith('crater'):
+        try:
+            socket.gethostbyname('hercules')
+        except:
             self.skip("those tests require specific DB configuration")
-        self.host = 'localhost' # None
+        self.host = 'hercules'
         self.db = 'template1'
-        self.user = 'adim'
-        self.passwd = 'adim'
-        
+        self.user = getlogin()
+        self.passwd = getlogin()
+
     def testPsyco(self):
         set_prefered_driver('postgres', 'psycopg')
         try:
@@ -96,8 +107,12 @@ class GetCnxTC(TestCase):
         except Exception, ex:
             # no mysql running ?
             import MySQLdb
-            if not (isinstance(ex, MySQLdb.OperationalError) and ex.args[0] == 2003):
-                raise
+            if isinstance(ex, MySQLdb.OperationalError):
+                if ex.args[0] == 1045: # find MysqlDb
+                    self.skip('mysql test requires a specific configuration')
+                elif ex.args[0] != 2003:
+                    raise
+            raise
 
     def test_connection_wrap(self):
         """Tests the connection wrapping"""
@@ -114,7 +129,7 @@ class GetCnxTC(TestCase):
                              quiet=1, pywrap = True)
         self.failUnless(isinstance(cnx, PyConnection),
                         'cnx should be a PyConnection instance')
-        
+
 
     def test_cursor_wrap(self):
         """Tests cursor wrapping"""
@@ -151,7 +166,7 @@ class DBAPIAdaptersTC(TestCase):
 
     def test_raise(self):
         self.assertRaises(UnknownDriver, get_dbapi_compliant_module, 'pougloup')
-        
+
     def test_pgdb_types(self):
         """Tests that NUMBER really wraps all number types"""
         PREFERED_DRIVERS['postgres'] = ['pgdb']
@@ -160,8 +175,8 @@ class DBAPIAdaptersTC(TestCase):
             module = get_dbapi_compliant_module('postgres')
         except ImportError:
             self.skip('postgresql pgdb module not installed')
-        number_types = ('int2', 'int4', 'serial', 
-                        'int8', 'float4', 'float8', 
+        number_types = ('int2', 'int4', 'serial',
+                        'int8', 'float4', 'float8',
                         'numeric', 'bool', 'money', 'decimal')
         for num_type in number_types:
             yield self.assertEquals, num_type, module.NUMBER
@@ -173,23 +188,23 @@ class DBAPIAdaptersTC(TestCase):
         try:
             module = get_dbapi_compliant_module('postgres')
         except ImportError:
-            self.skip('postgresql dbapi module not installed')            
+            self.skip('postgresql dbapi module not installed')
         try:
             binary = module.BINARY
         except AttributeError, err:
             raise
-            self.fail(str(err))        
+            self.fail(str(err))
 
     def test_adv_func_helper(self):
         try:
             module = get_dbapi_compliant_module('postgres')
         except ImportError:
-            self.skip('postgresql dbapi module not installed')            
+            self.skip('postgresql dbapi module not installed')
         self.failUnless(isinstance(module.adv_func_helper, _PGAdvFuncHelper))
         try:
             module = get_dbapi_compliant_module('sqlite')
         except ImportError:
-            self.skip('sqlite dbapi module not installed')            
+            self.skip('sqlite dbapi module not installed')
         self.failUnless(isinstance(module.adv_func_helper, _SqliteAdvFuncHelper))
 
 
@@ -223,7 +238,7 @@ class DBAPIAdaptersTC(TestCase):
         self.assertEquals(pghelper.func_sqlname('MYFUNC'), 'MYFUNC')
         self.assertEquals(mshelper.func_sqlname('MYFUNC'), 'MYF')
         self.assertEquals(slhelper.func_sqlname('MYFUNC'), 'SQLITE_MYFUNC')
-            
+
 
 if __name__ == '__main__':
     unittest_main()
